Title: [147637] trunk/Source
Revision
147637
Author
[email protected]
Date
2013-04-04 09:18:30 -0700 (Thu, 04 Apr 2013)

Log Message

[Qt] docs: Fix module name format
https://bugs.webkit.org/show_bug.cgi?id=113209

Patch by Sze Howe Koh <[email protected]> on 2013-04-04
Reviewed by Jocelyn Turcotte.

Make QDoc-generated documentation follow the conventions at
http://qt-project.org/wiki/Spelling_Module_Names_in_Qt_Documentation

Source/WebKit/qt:

* Api/qwebdatabase.cpp:
* Api/qwebkitglobal.cpp:
* Api/qwebpluginfactory.cpp:
* Api/qwebsettings.cpp:
* WidgetApi/qgraphicswebview.cpp:
* WidgetApi/qwebframe.cpp:
* WidgetApi/qwebpage.cpp:
* WidgetApi/qwebview.cpp:
* docs/qtwebkit-bridge.qdoc:
* docs/qtwebkit-goes-mobile.qdoc:
* docs/qtwebkit.qdoc:

Source/WebKit2:

* UIProcess/API/qt/qquickwebview.cpp:

Modified Paths

Diff

Modified: trunk/Source/WebKit/qt/Api/qwebdatabase.cpp (147636 => 147637)


--- trunk/Source/WebKit/qt/Api/qwebdatabase.cpp	2013-04-04 16:17:00 UTC (rev 147636)
+++ trunk/Source/WebKit/qt/Api/qwebdatabase.cpp	2013-04-04 16:18:30 UTC (rev 147637)
@@ -46,7 +46,7 @@
 
     WebKit uses SQLite to create and access the local SQL databases. The location of the database
     file in the local file system is returned by fileName(). You can access the database directly
-    through the QtSql database module.
+    through the \l{Qt SQL} database module.
 
     For each database the web site can define an expectedSize(). The current size of the database
     in bytes is returned by size().
@@ -131,7 +131,7 @@
 /*!
     Returns the file name of the web database.
 
-    The name can be used to access the database through the QtSql database module, for example:
+    The name can be used to access the database through the \l{Qt SQL} database module, for example:
     \code
       QWebDatabase webdb = ...
       QSqlDatabase sqldb = QSqlDatabase::addDatabase("QSQLITE", "myconnection");

Modified: trunk/Source/WebKit/qt/Api/qwebkitglobal.cpp (147636 => 147637)


--- trunk/Source/WebKit/qt/Api/qwebpluginfactory.cpp	2013-04-04 16:17:00 UTC (rev 147636)
+++ trunk/Source/WebKit/qt/Api/qwebpluginfactory.cpp	2013-04-04 16:18:30 UTC (rev 147637)
@@ -34,7 +34,7 @@
     <object type="application/x-pdf" data="" width="500" height="400"></object>
     \endcode
 
-    QtWebkit will natively handle the most basic data types like \c{text/html} and
+    Qt WebKit will natively handle the most basic data types like \c{text/html} and
     \c{image/jpeg}, but for any advanced or custom data types you will need to
     provide a handler yourself.
 

Modified: trunk/Source/WebKit/qt/Api/qwebsettings.cpp (147636 => 147637)


--- trunk/Source/WebKit/qt/Api/qwebsettings.cpp	2013-04-04 16:17:00 UTC (rev 147636)
+++ trunk/Source/WebKit/qt/Api/qwebsettings.cpp	2013-04-04 16:18:30 UTC (rev 147637)
@@ -344,7 +344,7 @@
     Support for browser plugins can enabled by setting the
     \l{QWebSettings::PluginsEnabled}{PluginsEnabled} attribute. For many applications,
     this attribute is enabled for all pages by setting it on the
-    \l{globalSettings()}{global settings object}. QtWebKit will always ignore this setting
+    \l{globalSettings()}{global settings object}. Qt WebKit will always ignore this setting
     when processing Qt plugins. The decision to allow a Qt plugin is made by the client
     in its reimplementation of QWebPage::createPlugin().
 
@@ -427,7 +427,7 @@
 
     \value AutoLoadImages Specifies whether images are automatically loaded in
         web pages. This is enabled by default.
-    \value DnsPrefetchEnabled Specifies whether QtWebkit will try to pre-fetch DNS entries to
+    \value DnsPrefetchEnabled Specifies whether Qt WebKit will try to pre-fetch DNS entries to
         speed up browsing. This only works as a global attribute. Only for Qt 4.6 and later. This is disabled by default.
     \value _javascript_Enabled Enables or disables the running of _javascript_
         programs. This is enabled by default
@@ -788,7 +788,7 @@
 }
 
 /*!
-    Sets \a graphic to be drawn when QtWebKit needs to draw an image of the
+    Sets \a graphic to be drawn when Qt WebKit needs to draw an image of the
     given \a type.
 
     For example, when an image cannot be loaded, the pixmap specified by

Modified: trunk/Source/WebKit/qt/ChangeLog (147636 => 147637)


--- trunk/Source/WebKit/qt/ChangeLog	2013-04-04 16:17:00 UTC (rev 147636)
+++ trunk/Source/WebKit/qt/ChangeLog	2013-04-04 16:18:30 UTC (rev 147637)
@@ -1,3 +1,25 @@
+2013-04-04  Sze Howe Koh  <[email protected]>
+
+        [Qt] docs: Fix module name format
+        https://bugs.webkit.org/show_bug.cgi?id=113209
+
+        Reviewed by Jocelyn Turcotte.
+
+        Make QDoc-generated documentation follow the conventions at
+        http://qt-project.org/wiki/Spelling_Module_Names_in_Qt_Documentation
+
+        * Api/qwebdatabase.cpp:
+        * Api/qwebkitglobal.cpp:
+        * Api/qwebpluginfactory.cpp:
+        * Api/qwebsettings.cpp:
+        * WidgetApi/qgraphicswebview.cpp:
+        * WidgetApi/qwebframe.cpp:
+        * WidgetApi/qwebpage.cpp:
+        * WidgetApi/qwebview.cpp:
+        * docs/qtwebkit-bridge.qdoc:
+        * docs/qtwebkit-goes-mobile.qdoc:
+        * docs/qtwebkit.qdoc:
+
 2013-03-28  Jesus Sanchez-Palencia  <[email protected]>
 
         [Qt] Switch ContextMenu implementation to CROSS_PLATFORM_CONTEXT_MENU

Modified: trunk/Source/WebKit/qt/WidgetApi/qgraphicswebview.cpp (147636 => 147637)


--- trunk/Source/WebKit/qt/WidgetApi/qgraphicswebview.cpp	2013-04-04 16:17:00 UTC (rev 147636)
+++ trunk/Source/WebKit/qt/WidgetApi/qgraphicswebview.cpp	2013-04-04 16:18:30 UTC (rev 147637)
@@ -145,7 +145,7 @@
     \since 4.6
 
     An instance of this class renders Web content from a URL or supplied as data, using
-    features of the QtWebKit module.
+    features of the Qt WebKit module.
 
     If the width and height of the item are not set, they will default to 800 and 600,
     respectively. If the Web page contents is larger than that, scrollbars will be shown

Modified: trunk/Source/WebKit/qt/WidgetApi/qwebframe.cpp (147636 => 147637)


--- trunk/Source/WebKit/qt/WidgetApi/qwebframe.cpp	2013-04-04 16:17:00 UTC (rev 147636)
+++ trunk/Source/WebKit/qt/WidgetApi/qwebframe.cpp	2013-04-04 16:18:30 UTC (rev 147637)
@@ -242,7 +242,7 @@
 
     Qt properties will be exposed as _javascript_ properties and slots as
     _javascript_ methods.
-    The interaction between C++ and _javascript_ is explained in the documentation of the \l{The QtWebKit Bridge}{QtWebKit bridge}.
+    The interaction between C++ and _javascript_ is explained in the documentation of the \l{The Qt WebKit Bridge}{Qt WebKit bridge}.
 
     If you want to ensure that your QObjects remain accessible after loading a
     new URL, you should add them in a slot connected to the

Modified: trunk/Source/WebKit/qt/WidgetApi/qwebpage.cpp (147636 => 147637)


--- trunk/Source/WebKit/qt/WidgetApi/qwebpage.cpp	2013-04-04 16:17:00 UTC (rev 147636)
+++ trunk/Source/WebKit/qt/WidgetApi/qwebpage.cpp	2013-04-04 16:18:30 UTC (rev 147637)
@@ -1682,7 +1682,7 @@
 
 /*!
     This function can be called to trigger the specified \a action.
-    It is also called by QtWebKit if the user triggers the action, for example
+    It is also called by Qt WebKit if the user triggers the action, for example
     through a context menu item.
 
     If \a action is a checkable action then \a checked specified whether the action

Modified: trunk/Source/WebKit/qt/WidgetApi/qwebview.cpp (147636 => 147637)


--- trunk/Source/WebKit/qt/WidgetApi/qwebview.cpp	2013-04-04 16:17:00 UTC (rev 147636)
+++ trunk/Source/WebKit/qt/WidgetApi/qwebview.cpp	2013-04-04 16:18:30 UTC (rev 147637)
@@ -78,7 +78,7 @@
 
     \inmodule QtWebKit
 
-    QWebView is the main widget component of the QtWebKit web browsing module.
+    QWebView is the main widget component of the Qt WebKit web browsing module.
     It can be used in various applications to display web content live from the
     Internet.
 
@@ -144,7 +144,7 @@
     \image qwebview-diagram.png
 
     \note It is possible to use QWebPage and QWebFrame, without using QWebView,
-    if you do not require QWidget attributes. Nevertheless, QtWebKit depends
+    if you do not require QWidget attributes. Nevertheless, Qt WebKit depends
     on QtGui, so you should use a QApplication instead of QCoreApplication.
 
     \sa {Previewer Example}, {Web Browser}, {Form Extractor Example},

Modified: trunk/Source/WebKit/qt/docs/qtwebkit-bridge.qdoc (147636 => 147637)


--- trunk/Source/WebKit/qt/docs/qtwebkit-bridge.qdoc	2013-04-04 16:17:00 UTC (rev 147636)
+++ trunk/Source/WebKit/qt/docs/qtwebkit-bridge.qdoc	2013-04-04 16:18:30 UTC (rev 147637)
@@ -1,19 +1,19 @@
 /*!
     \inmodule QtWebKit
     \page qtwebkit-bridge.html
-    \title The QtWebKit Bridge
-    \contentspage QtWebKit
+    \title The Qt WebKit Bridge
+    \contentspage Qt WebKit
     \section1 Overview
     \section2 The technology
 
-    The QtWebKit bridge is a mechanism that extends WebKit's _javascript_ environment to access native
+    The Qt WebKit bridge is a mechanism that extends WebKit's _javascript_ environment to access native
     objects represented as \l{QObject}s. It takes advantage of the \l{QObject} introspection,
     a part of the \l{Object Model}, which makes it easy to integrate with the dynamic _javascript_ environment.
     For example \l{QObject} properties map directly to _javascript_ properties.
 
     \section2 Use Cases
 
-    There are two main use cases for the QtWebKit bridge: web content in native applications and thin clients.
+    There are two main use cases for the Qt WebKit bridge: web content in native applications and thin clients.
 
     \section3 Web Content in Native Applications
 
@@ -25,7 +25,7 @@
     or \l{QtDeclarative}. The music store, which shows dynamic content
     from the Internet and gets modified rapidly, is best authored in HTML and maintained on the server.
 
-    With the QtWebKit bridge, the music store component can interact with native parts of the application,
+    With the Qt WebKit bridge, the music store component can interact with native parts of the application,
     for example, when a file needs to be saved to a specific location.
 
     \section3 Thin Clients
@@ -43,22 +43,22 @@
 
     \section2 Difference from Other Bridge Technologies
 
-    Of course, QtWebKit is not the only bridge technology out there. NPAPI, for example,
+    Of course, Qt WebKit is not the only bridge technology out there. NPAPI, for example,
     is a long-time standard for web-native bridging. Due to Qt's meta-object system, full applications
-    leveraging web technologies are much easier to develop with the QtWebKit bridge than with NPAPI. NPAPI, however, is better
+    leveraging web technologies are much easier to develop with the Qt WebKit bridge than with NPAPI. NPAPI, however, is better
     for cross-browser plugins, due to it being an accepted standard.
 
     When developing a plugin for a browser, NPAPI is recommended. When developing a full application
-    utilizing HTML-rendering, the QtWebKit bridge is recommended.
+    utilizing HTML-rendering, the Qt WebKit bridge is recommended.
 
-    \section2 Relationship with QtScript
+    \section2 Relationship with Qt Script
 
-    The QtWebKit bridge is similar to \l{QtScript}, especially for some of the features described in the
-    \l{Making Applications Scriptable} page. However, Qt 4.7 does not provide the full QtScript API for web applications.
+    The Qt WebKit bridge is similar to \l{Qt Script}, especially for some of the features described in the
+    \l{Making Applications Scriptable} page. However, Qt 4.7 does not provide the full Qt Script API for web applications.
     Full support is planned for future versions. You might notice that some of the features
     described here are an exact copy of the ones described in the \l{Making Applications Scriptable} page. That is because
-    the QtWebKit bridge is a subset of that functionality, and this page tries to capture the full
-    capabilities available through the QtWebKit bridge specifically.
+    the Qt WebKit bridge is a subset of that functionality, and this page tries to capture the full
+    capabilities available through the Qt WebKit bridge specifically.
 
     \section1 Accessing QObjects
 
@@ -74,9 +74,9 @@
 
     \section2 Using Signals and Slots
 
-    The QtWebKit bridge adapts Qt's central \l{Signals and Slots} feature for
+    The Qt WebKit bridge adapts Qt's central \l{Signals and Slots} feature for
     scripting. There are three principal ways to use signals and slots
-    with the QtWebKit bridge:
+    with the Qt WebKit bridge:
 
     \list
     \li \b{Hybrid C++/script}: C++ application code connects a
@@ -100,7 +100,7 @@
     script function.
     \endlist
 
-    Note that QtScript functions such as qScriptConnect are unavilable in the web environment.
+    Note that Qt Script functions such as qScriptConnect are unavilable in the web environment.
 
     \section3 Signal to Function Connections
 
@@ -117,7 +117,7 @@
     \snippet webkitsnippets/qtwebkit_bridge_snippets.cpp 8
 
     When the argument is a slot of a QObject, the argument types of the
-    signal and the slot do not have to be compatible. If possible, the QtWebKit
+    signal and the slot do not have to be compatible. If possible, the Qt WebKit
     bridge converts the signal arguments such that they match the slot argument.
 
     To disconnect a slot from a signal, you call the signal's
@@ -194,7 +194,7 @@
 
     \section3 Overloaded Signals and Slots
 
-    When a signal or slot is overloaded, the QtWebKit bridge will attempt to
+    When a signal or slot is overloaded, the Qt WebKit bridge will attempt to
     pick the right overload based on the actual types of the QScriptValue arguments
     involved in the function invocation. For example, if your class has slots
     \c{myOverloadedSlot(int)} and \c{myOverloadedSlot(QString)}, the following
@@ -208,7 +208,7 @@
 
     \snippet webkitsnippets/qtwebkit_bridge_snippets.cpp 21
 
-    If the overloads have different number of arguments, the QtWebKit bridge will
+    If the overloads have different number of arguments, the Qt WebKit bridge will
     pick the overload with the argument count that best matches the
     actual number of arguments passed to the slot.
 
@@ -260,7 +260,7 @@
 
     When calling slots, receiving signals or accessing properties, usually some payload is involved.
     For example, a property "text" might return a \l{QString} parameter.
-    The QtWebKit bridge does the job of converting between a given _javascript_ data-type, and the
+    The Qt WebKit bridge does the job of converting between a given _javascript_ data-type, and the
     expected or given Qt type. Each Qt type has a coresponding set of rules of how _javascript_ treats it.
 
     The data type conversions are also applicable for the data returned from non-void invokable methods.
@@ -269,7 +269,7 @@
 
     All Qt numeric data types are converted to or from a _javascript_ number. These include int, short, float,
     double, and the portable Qt types (qreal, qint etc). A special case is \l{QChar}.
-    If a slot expects a QChar, the QtWebKit bridge uses the Unicode value in case of a number and the first character in case of a string.
+    If a slot expects a QChar, the Qt WebKit bridge uses the Unicode value in case of a number and the first character in case of a string.
 
     Note that non-standard (typedef'ed) number types are not automatically converted to
     or from a _javascript_ number - we suggest to use standard number types for signals, slots
@@ -280,31 +280,31 @@
 
     \section3 Strings
 
-    When _javascript_ accesses methods or properties that expect a \l{QString}, the QtWebKit bridge
+    When _javascript_ accesses methods or properties that expect a \l{QString}, the Qt WebKit bridge
     will automatically convert the value to a string (if it is not already a string), using the
     built-in _javascript_ toString method.
 
-    When a QString is passed to _javascript_ from a signal or a property, the QtWebKit bridge
+    When a QString is passed to _javascript_ from a signal or a property, the Qt WebKit bridge
     converts it into a _javascript_ string.
 
     \section3 Date & Time
 
     Both \l{QDate}, \l{QTime} and \l{QDateTime} are automatically translated to or from the _javascript_
     Date object. If a number is passed as an argument to a method that expects one of the date/time
-    types, the QtWebKit bridge treats it as a timestamp. If a sting is passed, QtWebKit
+    types, the Qt WebKit bridge treats it as a timestamp. If a sting is passed, Qt WebKit
     tries the different Qt date parsing functions to perform the right translation.
 
     \section3 Regular Expressions
 
-    The QtWebKit bridge automatically converts a _javascript_ RegEx object to a \l{QRegExp}.
+    The Qt WebKit bridge automatically converts a _javascript_ RegEx object to a \l{QRegExp}.
     If a string is passed to a method expecting a \l{QRegExp}, the string is converted
     to a \l{QRegExp}.
 
     \section3 Lists
 
-    The QtWebKit bridge treats several types of lists in a special way: \l{QVariantList}, \l{QStringList},
+    The Qt WebKit bridge treats several types of lists in a special way: \l{QVariantList}, \l{QStringList},
     \l{QObjectList} and \l{QList}<int>. When a slot or property expects one of those list types,
-    the QtWebKit bridge tries to convert a _javascript_ array into that type, converting each of
+    the Qt WebKit bridge tries to convert a _javascript_ array into that type, converting each of
     the array's elements to the single-element type of the list.
 
     The most useful type of list is \l{QVariantList}, which can be converted to and from any
@@ -326,7 +326,7 @@
 
     \section3 QVariants
 
-    When a slot or property accepts a \l{QVariant}, the QtWebKit bridge creates a \l{QVariant} that best
+    When a slot or property accepts a \l{QVariant}, the Qt WebKit bridge creates a \l{QVariant} that best
     matches the argument passed by _javascript_. A string, for example, becomes a \l{QVariant} holding a \l{QString},
     a normal JSON object becomes a \l{QVariantMap}, and a _javascript_ array becomes a \l{QVariantList}.
 
@@ -341,7 +341,7 @@
     Pointers to a \l{QObject} or a \l{QWidget} can be used in signals, slots and properties. This object
     can then be used like an object that is exposed directly. Its slots can be invoked, its signals connected to, etc.
     However, this functionality is fairly limited - the type used has to be \l{QObject}* or \l{QWidget}*. If the type
-    specified is a pointer to a non-\l{QWidget} subclass of \l{QObject}, the QtWebKit bridge does not recognize it as
+    specified is a pointer to a non-\l{QWidget} subclass of \l{QObject}, the Qt WebKit bridge does not recognize it as
     a \l{QObject}.
 
     In general its advised to use care when passing \l{QObject}s as arguments, as those objects don't become owned by
@@ -352,7 +352,7 @@
 
     \since 4.7
 
-    The QtWebKit bridge handles \l{QPixmap}s and \l{QImage}s in a special way. Since QtWebKit stores \l{QPixmap}s to
+    The Qt WebKit bridge handles \l{QPixmap}s and \l{QImage}s in a special way. Since Qt WebKit stores \l{QPixmap}s to
     represent HTML images, \l{QPixmap}s coming from the native environment can be used directly inside WebKit.
     A \l{QImage} or a \l{QPixmap} coming from Qt is converted to an intermediate _javascript_ object,
     which can be represented like this:
@@ -374,7 +374,7 @@
     \snippet webkitsnippets/qtwebkit_bridge_snippets.cpp 3
 
     When a Qt object expects a \l{QImage} or a \l{QPixmap} as input, and the argument passed is an HTML image element,
-    the QtWebKit bridge would convert the pixmap assigned to that image element into a \l{QPixmap} or a \l{QImage}.
+    the Qt WebKit bridge would convert the pixmap assigned to that image element into a \l{QPixmap} or a \l{QImage}.
 
     \since 4.7
 
@@ -399,7 +399,7 @@
 
     \section2 Limiting the Scope of the Hybrid Layer
 
-    When using QtWebKit's hybrid features, it is a common pitfall to make the API exposed to _javascript_ very rich and
+    When using Qt WebKit's hybrid features, it is a common pitfall to make the API exposed to _javascript_ very rich and
     use all its features. This, however, leads to complexity and can create bugs that are hard to find.
     Instead, it is advisable to keep the hybrid layer small and manageable: create a gate only when
     there's an actual need for it, i.e. there's a new native enabler that requires a direct interface

Modified: trunk/Source/WebKit/qt/docs/qtwebkit-goes-mobile.qdoc (147636 => 147637)


--- trunk/Source/WebKit/qt/docs/qtwebkit-goes-mobile.qdoc	2013-04-04 16:17:00 UTC (rev 147636)
+++ trunk/Source/WebKit/qt/docs/qtwebkit-goes-mobile.qdoc	2013-04-04 16:18:30 UTC (rev 147637)
@@ -1,11 +1,11 @@
 /*!
     \inmodule QtWebKit
     \page qtwebkit-goes-mobile.html
-    \title QtWebKit Goes Mobile
-    \contentspage QtWebKit
+    \title Qt WebKit Goes Mobile
+    \contentspage Qt WebKit
     \section1 Overview
 
-    A lot of effort has been put into QtWebKit to make it attractive for
+    A lot of effort has been put into Qt WebKit to make it attractive for
     use on mobile devices.
 
     The goal of this tutorial is to help you understand the mobile
@@ -24,7 +24,7 @@
 
     Here we set up a \l{QGraphicsView} application and add a
     \l{QGraphicsWebView} to the scene. Notice
-    that we're disabling the scrollbars on the QGraphicsView because QtWebKit
+    that we're disabling the scrollbars on the QGraphicsView because Qt WebKit
     handles scrolling and scrollbars automatically. This is to allow scrolling
     optimizations and to enable web authors to interact with the scrollbars,
     for instance, to style them differently.
@@ -53,7 +53,7 @@
     One way to overcome this issue, is to do all loading, laying out and
     painting (basically all non-UI related work) in another thread or process, and
     just blit the result from the web process/thread to the UI. There is research
-    in progress to enable this for a future version of QtWebKit, using WebKit2, but for now,
+    in progress to enable this for a future version of Qt WebKit, using WebKit2, but for now,
     freezing the backing store can help when performing a zooming operation, for instance.
     This will be discussed later, in the \l{#Enabling the Tiling}{Enabling the Tiling} section.
 
@@ -125,7 +125,7 @@
     are written with a desktop browser in mind, that makes only very few sites
     fit into the width of a mobile device.
 
-    QtWebKit has a way to force a layout to a given width or height. What really
+    Qt WebKit has a way to force a layout to a given width or height. What really
     matters here is the width. If you lay out a page to a given width, it will get
     that width and images might be cropped. The width or height is also used for
     laying out fixed elements, but when we resize the \l{QGraphicsWebView} to the
@@ -149,7 +149,7 @@
     \section1 The 'viewport' Meta-Tag
 
     As some sites do not work with 960 pixels width or want to have control of
-    how the page is laid out, QtWebKit, Android, Firefox Mobile and
+    how the page is laid out, Qt WebKit, Android, Firefox Mobile and
     the iPhone Safari browser support a meta-tag called \c viewport. This makes
     it possible for a web page to let the browser know how it wants to be shown.
     More info can be found in the

Modified: trunk/Source/WebKit/qt/docs/qtwebkit.qdoc (147636 => 147637)


--- trunk/Source/WebKit/qt/docs/qtwebkit.qdoc	2013-04-04 16:17:00 UTC (rev 147636)
+++ trunk/Source/WebKit/qt/docs/qtwebkit.qdoc	2013-04-04 16:18:30 UTC (rev 147637)
@@ -32,7 +32,7 @@
 
 /*!
     \page qtwebkitwidgets-index.html
-    \title Qt Webkit Widgets
+    \title Qt WebKit Widgets
     \ingroup modules
 
     \brief The Qt WebKit Widgets module provides a web browser engine as well as
@@ -49,7 +49,7 @@
 
     A bridge between the _javascript_ execution environment and the Qt object
     model makes it possible for custom QObjects to be scripted. For detailed
-    documentation see \l{The QtWebkit Bridge}.
+    documentation see \l{The Qt WebKit Bridge}.
     Integration with the Qt networking module enables Web pages to be transparently loaded
     from Web servers, the local file system or even the Qt resource system.
 
@@ -60,7 +60,7 @@
     QtWebKit has been enhanced to become more attractive on the mobile front as well.
     For more information see \l{QtWebKit Goes Mobile}.
 
-    QtWebKit is based on the Open Source WebKit engine. More information about
+    Qt WebKit is based on the Open Source WebKit engine. More information about
     WebKit itself can be found on the \l{WebKit Open Source Project} Web site.
 
     \section1 Including In Your Project
@@ -77,10 +77,10 @@
 
     \section1 Notes
 
-    \note Building the QtWebKit module with debugging symbols is problematic
+    \note Building the Qt WebKit module with debugging symbols is problematic
     on many platforms due to the size of the WebKit engine. We recommend
     building the module only in release mode for embedded platforms.
-    Currently QtWebKit will always be compiled without debugging symbols
+    Currently Qt WebKit will always be compiled without debugging symbols
     when using gcc. Take a look at the last lines of
     \c{src/3rdparty/webkit/Source/WebCore/WebCore.pro} if you need to change this.
 
@@ -111,7 +111,7 @@
     may contain many child frames.
 
     Individual elements of an HTML document can be accessed via DOM _javascript_
-    interfaces from within a web page. The equivalent of this API in QtWebKit
+    interfaces from within a web page. The equivalent of this API in Qt WebKit
     is represented by QWebElement. QWebElement objects are obtained using QWebFrame's
     \l{QWebFrame::}{findAllElements()} and \l{QWebFrame::}{findFirstElement()}
     functions with CSS selector queries.
@@ -196,7 +196,7 @@
     can be found in the \c{src/3rdparty/webkit/VERSION} file supplied with Qt.
 
     Qt Commercial Edition licensees that wish to distribute applications that
-    use the QtWebKit module need to be aware of their obligations under the
+    use the Qt WebKit module need to be aware of their obligations under the
     GNU Library General Public License (LGPL).
 
     Developers using the Open Source Edition can choose to redistribute

Modified: trunk/Source/WebKit2/ChangeLog (147636 => 147637)


--- trunk/Source/WebKit2/ChangeLog	2013-04-04 16:17:00 UTC (rev 147636)
+++ trunk/Source/WebKit2/ChangeLog	2013-04-04 16:18:30 UTC (rev 147637)
@@ -1,3 +1,15 @@
+2013-04-04  Sze Howe Koh  <[email protected]>
+
+        [Qt] docs: Fix module name format
+        https://bugs.webkit.org/show_bug.cgi?id=113209
+
+        Reviewed by Jocelyn Turcotte.
+
+        Make QDoc-generated documentation follow the conventions at
+        http://qt-project.org/wiki/Spelling_Module_Names_in_Qt_Documentation
+
+        * UIProcess/API/qt/qquickwebview.cpp:
+
 2013-04-04  Mikhail Pozdnyakov  <[email protected]>
 
         [WK2][EFL] WebView should own view size

Modified: trunk/Source/WebKit2/UIProcess/API/qt/qquickwebview.cpp (147636 => 147637)


--- trunk/Source/WebKit2/UIProcess/API/qt/qquickwebview.cpp	2013-04-04 16:17:00 UTC (rev 147636)
+++ trunk/Source/WebKit2/UIProcess/API/qt/qquickwebview.cpp	2013-04-04 16:18:30 UTC (rev 147637)
@@ -2291,7 +2291,7 @@
 
     \row
     \li InternalErrorDomain
-    \li Content fails to be interpreted by QtWebKit.
+    \li Content fails to be interpreted by Qt WebKit.
 
     \row
     \li NetworkErrorDomain
_______________________________________________
webkit-changes mailing list
[email protected]
https://lists.webkit.org/mailman/listinfo/webkit-changes

Reply via email to
--- trunk/Source/WebKit/qt/Api/qwebkitglobal.cpp	2013-04-04 16:17:00 UTC (rev 147636)
+++ trunk/Source/WebKit/qt/Api/qwebkitglobal.cpp	2013-04-04 16:18:30 UTC (rev 147637)
@@ -34,7 +34,7 @@
     and behaviour.
 
     The evolution of this version is bound to the releases of Apple's
-    Safari browser. For a version specific to the QtWebKit library,
+    Safari browser. For a version specific to the Qt WebKit module,
     see QTWEBKIT_VERSION
 
     \sa QWebPage::userAgentForUrl()
@@ -77,11 +77,11 @@
     \relates QWebPage
 
     This macro expands a numeric value of the form 0xMMNNPP (MM =
-    major, NN = minor, PP = patch) that specifies QtWebKit's version
-    number. For example, if you compile your application against QtWebKit
+    major, NN = minor, PP = patch) that specifies Qt WebKit's version
+    number. For example, if you compile your application against Qt WebKit
     2.1.2, the QTWEBKIT_VERSION macro will expand to 0x020102.
 
-    You can use QTWEBKIT_VERSION to use the latest QtWebKit API where
+    You can use QTWEBKIT_VERSION to use the latest Qt WebKit API where
     available.
 
     \sa QT_VERSION
@@ -91,7 +91,7 @@
     \macro QTWEBKIT_VERSION_STR
     \relates QWebPage
 
-    This macro expands to a string that specifies QtWebKit's version number
+    This macro expands to a string that specifies Qt WebKit's version number
     (for example, "2.1.2"). This is the version against which the
     application is compiled.
 
@@ -109,7 +109,7 @@
 
     \code
     #if QTWEBKIT_VERSION >= QTWEBKIT_VERSION_CHECK(2, 1, 0)
     // code to use API new in QtWebKit 2.1.0
     #endif
     \endcode
 */
@@ -109,7 +109,7 @@
     \code
     #if QTWEBKIT_VERSION >= QTWEBKIT_VERSION_CHECK(2, 1, 0)
-    // code to use API new in QtWebKit 2.1.0
+    // code to use API new in Qt WebKit 2.1.0
     #endif
     \endcode

Modified: trunk/Source/WebKit/qt/Api/qwebpluginfactory.cpp (147636 => 147637)

